@@ -1,15 +1,26 @@
 #!/usr/bin/env bash
-
+aCurrentPath="$PWD"
 aScriptPath=${BASH_SOURCE%/*}; if [ -d "${aScriptPath}" ]; then cd "$aScriptPath"; fi; aScriptPath="$PWD";
+cd ${aCurrentPath}
 
 # ----- For compatibility with external application using CASROOT -----
 if [ "${CASROOT}" == "" ]; then
-  export CASROOT="/usr/local/share/opencascade"
+  # Get the last directory name from the path
+  lastDir=$(basename "$aScriptPath")
+  # Check if last directory is exactly bin, bind, or bini
+  if [ "$lastDir" = "bin" ] || [ "$lastDir" = "bind" ] || [ "$lastDir" = "bini" ]; then
+    # If path contains binary folder, go one level up
+    export CASROOT=$(cd "$aScriptPath/.." && pwd)
+  else
+    # Keep current location
+    export CASROOT="${aScriptPath}"
+  fi
+  cd ${aCurrentPath}
 fi
 
 # ----- Define path to 3rdparty products -----
 if [ "${THIRDPARTY_DIR}" == "" ]; then
-  export THIRDPARTY_DIR="/usr/obj/ports/opencascade-7.8.1/occt-V7_8_1"
+  export THIRDPARTY_DIR="/pobj/opencascade-7.9.3/OCCT-7_9_3"
 fi
 
 # ----- Read script arguments -----
@@ -23,7 +34,7 @@ shopt -u nocasematch
 
 # ----- Set path to 3rd party and OCCT libraries -----
 anArch=`uname -m`
-if [ "$anArch" != "x86_64" ] && [ "$anArch" != "ia64" ]; then
+if [ "$anArch" != "x86_64" ] && [ "$anArch" != "ia64" ] && [ "$anArch" != "aarch64" ] && [ "$anArch" != "arm64" ] && [ "$anArch" != "amd64" ]; then
   export ARCH="32";
 else
   export ARCH="64";
@@ -32,7 +43,6 @@ fi
 aSystem=`uname -s`
 if [ "$aSystem" == "Darwin" ]; then
   export WOKSTATION="mac";
-  export ARCH="64";
 else
   export WOKSTATION="lin";
 fi
