@@ -524,7 +524,7 @@ help checkprops {
     -deps DEPSILON: the epsilon defines relative precision to compare corresponding values
     -equal SHAPE: compare area\volume\length of input shapes. Puts error if its are not equal
     -notequal SHAPE: compare area\volume\length of input shapes. Puts error if its are equal
-    -skip: count shared shapes only once, skipping repeatitions
+    -skip: count shared shapes only once, skipping repetitions
   Options -l, -s and -v are independent and can be used in any order. Tolerance epsilon is the same for all options.
 }
 
@@ -1095,6 +1095,7 @@ help checkplatform {
     -windows : return 1 if current platform is 'Windows', otherwise return 0
     -linux   : return 1 if current platform is 'Linux', otherwise return 0
     -osx     : return 1 if current platform is 'MacOS X', otherwise return 0
+    -openbsd : return 1 if current platform is 'OpenBSD', otherwise return 0
 
   Only one option can be used at once.
   If no option is given, procedure will return the name of current platform.
@@ -1103,9 +1104,11 @@ proc checkplatform {args} {
     set check_for_windows false
     set check_for_linux false
     set check_for_macosx false
+    set check_for_openbsd false
 
     set options {{"-windows" check_for_windows 0}
                  {"-linux" check_for_linux 0}
+                 {"-openbsd" check_for_openbsd 0}
                  {"-osx" check_for_macosx 0}}
 
     _check_args ${args} ${options} "checkplatform"
@@ -1114,17 +1117,19 @@ proc checkplatform {args} {
         set current_platform Windows
     } elseif { $::tcl_platform(os) == "Linux" } {
         set current_platform Linux
+    } elseif { $::tcl_platform(os) == "OpenBSD" } {
+        set current_platform OpenBSD
     } elseif { $::tcl_platform(os) == "Darwin" } {
         set current_platform MacOS
     }
 
     # no args are given
-    if { !${check_for_windows} && !${check_for_linux} && !${check_for_macosx}} {
+    if { !${check_for_windows} && !${check_for_linux} && !${check_for_macosx} && !${check_for_openbsd}} {
         return ${current_platform}
     }
 
     # check usage of proc checkplatform
-    if { [expr [string is true ${check_for_windows}] + [string is true ${check_for_linux}] + [string is true ${check_for_macosx}] ] > 1} {
+    if { [expr [string is true ${check_for_windows}] + [string is true ${check_for_linux}] + [string is true ${check_for_macosx}] + [string is true ${check_for_openbsd}] ] > 1} {
         error "Error: wrong usage of command checkplatform, only single option can be used at once"
     }
 
@@ -1133,11 +1138,16 @@ proc checkplatform {args} {
         return 1
     }
 
-    # checking for Mac OS X platforms
+    # checking for Linux platforms
     if { ${check_for_linux} && ${current_platform} == "Linux" } {
         return 1
     }
 
+    # checking for OpenBSD platforms
+    if { ${check_for_openbsd} && ${current_platform} == "OpenBSD" } {
+        return 1
+    }
+
     # checking for Mac OS X platforms
     if { ${check_for_macosx} && ${current_platform} == "MacOS" } {
         return 1
